# Weaviate python client  <img alt='Weaviate logo' src='https://raw.githubusercontent.com/semi-technologies/weaviate/19de0956c69b66c5552447e84d016f4fe29d12c9/docs/assets/weaviate-logo.png' width='180' align='right' />

A python native client for easy interaction with a weaviate instance.

The client is tested for python 3.6 and higher.

## Documentation

- [Documentation](https://www.semi.technology/documentation/weaviate/current/client-libraries/python.html)

## Support

- [Stackoverflow for questions](https://stackoverflow.com/questions/tagged/weaviate)
- [Github for issues](https://github.com/semi-technologies/weaviate-python-client/issues)

## Contributing

- [How to Contribute](https://github.com/semi-technologies/weaviate/blob/master/CONTRIBUTE.md)

## Build Status

| Branch   | Status        |
| -------- |:-------------:|
| Master   | [![Build Status](https://travis-ci.com/semi-technologies/weaviate-python-client.svg)](https://travis-ci.com/semi-technologies/weaviate-python-client)
